@@ -1,4 +1,4 @@
-from __future__ import division
+from __future__ import division, unicode_literals
 
 
 try:
@@ -6,7 +6,6 @@ try:
 except ImportError:
     import pathlib2 as pathlib
 
-
 import zipp
 
 
@@ -45,9 +44,27 @@ def test_traverse_truediv(zipfile_abcde):
     assert e.read_text() == 'content of e'
 
 
+def test_traverse_simplediv(zipfile_abcde):
+    """
+    Disable the __future__.division when testing traversal.
+    """
+    code = compile(
+        source="zipp.Path(zipfile_abcde) / 'a'",
+        filename='(test)',
+        mode='eval',
+        dont_inherit=True,
+    )
+    eval(code)
+
+
 def test_pathlike_construction(zipfile_ondisk):
     """
     zipp.Path should be constructable from a path-like object
     """
     pathlike = pathlib.Path(str(zipfile_ondisk))
     zipp.Path(pathlike)
+
+
+def test_traverse_pathlike(zipfile_abcde):
+    root = zipp.Path(zipfile_abcde)
+    root / pathlib.Path('a')
